@@ -604,7 +604,7 @@ cal_backend_wcap_get_rid_string (ECalComponent *comp)
 	e_cal_component_free_range (&range);
 
 	if (icaltime_is_valid_time (tt) && !icaltime_is_null_time (tt))
-		return icaltime_as_ical_string (tt);
+		return icaltime_as_ical_string_r (tt);
 	else
 		return g_strdup ("0");
 }
@@ -1360,7 +1360,7 @@ write_cache_when_idle (CalBackendWCAP *wcap)
 	icalcomponent_add_property (icalcomp, prop);
 
 	g_hash_table_foreach (priv->instances, build_calendar, icalcomp);
-	buf = icalcomponent_as_ical_string (icalcomp);
+	buf = icalcomponent_as_ical_string_r (icalcomp);
 	result = gnome_vfs_write (handle, buf, strlen (buf) * sizeof (char), &out);
 	g_free (buf);
 	icalcomponent_free (icalcomp);
@@ -2064,7 +2064,7 @@ cal_backend_wcap_send_objects (ECalBackendSync *backend, EDataCal *cal, const ch
 			*users = g_list_prepend (*users, tmp);
 	}
 	g_object_unref (comp);
-	*modified_calobj = icalcomponent_as_ical_string (top_level);
+	*modified_calobj = icalcomponent_as_ical_string_r (top_level);
  cleanup:	
 	icalcomponent_free (top_level);
 	
@@ -2618,7 +2618,7 @@ cal_backend_wcap_get_timezone (ECalBackendSync *backend, EDataCal *cal,
 	if (!vtzcomp)
 		return GNOME_Evolution_Calendar_OtherError;
 
-	*object = icalcomponent_as_ical_string (vtzcomp);
+	*object = icalcomponent_as_ical_string_r (vtzcomp);
 	return GNOME_Evolution_Calendar_Success;
 }
 
