@@ -203,7 +203,7 @@ append_to_query_datetime (SoupURI *uri, const char *param, ECalComponentDateTime
 		return;
 	}
 	
-	string = icaltime_as_ical_string (*dt->value);
+	string = icaltime_as_ical_string_r (*dt->value);
 	append_to_query (uri, param, string);	
 	g_free (string);
 	e_cal_component_free_datetime (dt);
@@ -353,7 +353,7 @@ append_to_query_exdate_list (SoupURI *uri, const char *param, GSList *dt_list)
 		
 		if (!dt->value)
 			continue;
-		tstr = icaltime_as_ical_string (*dt->value);
+		tstr = icaltime_as_ical_string_r (*dt->value);
 		
 		if (string) {
 			string = g_strconcat (string, ";", tstr, NULL);
@@ -380,7 +380,7 @@ append_to_query_recur_list (SoupURI *uri, const char *param, GSList *r_list)
 		struct icalrecurrencetype *recur = l->data;
 		char *tmp = string, *enc;
 
-		enc = query_encode (icalrecurrencetype_as_string (recur), FALSE, ";=");
+		enc = query_encode (icalrecurrencetype_as_string_r (recur), FALSE, ";=");
 		if (string) {
 			string = g_strconcat (string, ";\"", enc, "\"", NULL);
 			g_free (tmp);
@@ -539,10 +539,10 @@ append_to_query_alarms (SoupURI *uri, SunOneConnection *connection, ECalComponen
 
 		e_cal_component_alarm_get_trigger (alarm, &trigger);
 		if (trigger.type == E_CAL_COMPONENT_ALARM_TRIGGER_ABSOLUTE)
-			dtstring = icaltime_as_ical_string (trigger.u.abs_time);
+			dtstring = icaltime_as_ical_string_r (trigger.u.abs_time);
 		else
 			dtstring =
-				g_strdup (icaldurationtype_as_ical_string (trigger.u.rel_duration));
+				g_strdup (icaldurationtype_as_ical_string_r (trigger.u.rel_duration));
 		
 		if (atype != NULL && dtstring != NULL) {
 			ECalComponentText text;
@@ -2162,11 +2162,11 @@ sunone_connection_fetchcomponents_by_lastmod (SunOneConnection *connection,
 	/* prepare the URI */
 	NEW_URI (fetch_uri);
 	if (!icaltime_is_null_time (dtstart))
-		tsstr = icaltime_as_ical_string (dtstart);
+		tsstr = icaltime_as_ical_string_r (dtstart);
 	else
 		tsstr = g_strdup ("0");
 	if (!icaltime_is_null_time (dtend))
-		testr = icaltime_as_ical_string (dtend);
+		testr = icaltime_as_ical_string_r (dtend);
 	else
 		testr = g_strdup ("0");
 	fetch_uri->path = g_strdup ("/fetchcomponents_by_lastmod.wcap");
@@ -2230,11 +2230,11 @@ sunone_connection_fetch_deletedcomponents (SunOneConnection *connection,
 	/* prepare the URI */
 	NEW_URI (fetch_uri);
 	if (!icaltime_is_null_time (dtstart))
-		tsstr = icaltime_as_ical_string (dtstart);
+		tsstr = icaltime_as_ical_string_r (dtstart);
 	else
 		tsstr = g_strdup ("0");
 	if (!icaltime_is_null_time (dtend))
-		testr = icaltime_as_ical_string (dtend);
+		testr = icaltime_as_ical_string_r (dtend);
 	else
 		testr = g_strdup ("0");
 	fetch_uri->path = g_strdup ("/fetch_deletedcomponents.wcap");
@@ -2285,11 +2285,11 @@ sunone_connection_get_freebusy (SunOneConnection *connection,
 	/* prepare the URI */
 	NEW_URI (fetch_uri);
 	if (!icaltime_is_null_time (dtstart))
-		tsstr = icaltime_as_ical_string (dtstart);
+		tsstr = icaltime_as_ical_string_r (dtstart);
 	else
 		tsstr = g_strdup ("0");
 	if (!icaltime_is_null_time (dtend))
-		testr = icaltime_as_ical_string (dtend);
+		testr = icaltime_as_ical_string_r (dtend);
 	else
 		testr = g_strdup ("0");
 	fetch_uri->path = g_strdup ("/get_freebusy.wcap");
@@ -2323,11 +2323,11 @@ sunone_connection_get_freebusy (SunOneConnection *connection,
 		/* prepare the URI */
 		NEW_URI (fetch_uri);
 		if (!icaltime_is_null_time (dtstart))
-			tsstr = icaltime_as_ical_string (dtstart);
+			tsstr = icaltime_as_ical_string_r (dtstart);
 		else
 			tsstr = g_strdup ("0");
 		if (!icaltime_is_null_time (dtend))
-			testr = icaltime_as_ical_string (dtend);
+			testr = icaltime_as_ical_string_r (dtend);
 		else
 			testr = g_strdup ("0");
 		fetch_uri->path = g_strdup ("/get_freebusy.wcap");
@@ -2373,7 +2373,7 @@ sunone_connection_import (SunOneConnection *connection, const char *calid, icalc
 
 	IS_CONNECTED (connection, SOUP_STATUS_CANT_CONNECT);
 
-	ical_string = icalcomponent_as_ical_string (icalcomp);
+	ical_string = icalcomponent_as_ical_string_r (icalcomp);
 	if (!ical_string)
 		return SOUP_STATUS_CANCELLED;
 
@@ -2744,7 +2744,7 @@ sunone_connection_storetodos (SunOneConnection *connection, const char *calid, i
 	/* Completed */
 	e_cal_component_get_completed (comp, &t);
 	if (t)
-		tstr = icaltime_as_ical_string (*t);
+		tstr = icaltime_as_ical_string_r (*t);
 	else
 		tstr = g_strdup ("0");
 	append_to_query (fetch_uri, "completed", tstr);
