@@ -598,8 +598,10 @@ static void render_pixbuf (GtkTreeViewColumn *column, GtkCellRenderer *renderer,
 	char *folder_type;
 
 	if (!initialised) {
-		folder_icons[FOLDER_ICON_NORMAL] = e_icon_factory_get_icon ("stock_normal", E_ICON_SIZE_MENU);
-		folder_icons[FOLDER_ICON_INVITATION] = e_icon_factory_get_icon ("stock_new-meeting", E_ICON_SIZE_MENU);
+		folder_icons[FOLDER_ICON_NORMAL] = e_icon_factory_get_icon
+			("stock_normal", GTK_ICON_SIZE_MENU);
+		folder_icons[FOLDER_ICON_INVITATION] = e_icon_factory_get_icon
+			("stock_new-meeting", GTK_ICON_SIZE_MENU);
 		initialised = TRUE;
 	}
 
