@@ -241,8 +241,9 @@ set_data_and_props (SunOneInvitationList *list, int row)
 
 	/* Send the icalendar code over */
 	top_level = toplevel_with_zones (list, comp);
-	string = icalcomponent_as_ical_string (top_level);
+	string = icalcomponent_as_ical_string_r (top_level);
 	set_data (BONOBO_WIDGET (priv->control), string);
+	g_free (string);
 	icalcomponent_free (top_level);
 }
 
